/*
 * Copyright(c)  2002  Rijkswaterstaat
 *                     Adviesdienst Verkeer en Vervoer
 *                     WSRA
 * File: CRAPTAB.C
 *
 * Regelprogramma vri:      vergelijk datum, dag en tijd
 *
 * datum:                   25-01-96
 *                          19-03-03 aanpassing aan FLASH
 *                                   apart getal voor eeuw
 *                          24-12-03 aanpassing m.b.t. EGGPARM()
 * versie:                  1.2
 */


#include "crtypes.h"
#include "crapcod.h"
#include "craptab.h"
#include "ccie_int.h"
#include "crapdef.h"


/*     BLOKKEN schema                                           */
struct BLOKKEN  BLOKKEN_tabel[] = {
/*     blok:    sg:     toewijzing:                             */
/*     BKl,     SGn,    PRIM + WSGR + ALT,                      */
       BK1,     SG02,   PRIM,
       BK2,     SG05,   PRIM,
       BK3,     SG09,   PRIM,
       STOP};


/*     CONFLICT- en (garantie)ontruimingstijden matrix          */
struct CONFLICT  CONFLICT_tabel[] = {
/*                                    instellingen              */
/*                                    van de tijden:            */
/*     sg:       conflicterende sg:   GO_TIJD:  O_TIJD:         */
/*     SGn,      SGj,                 x.y,      x.y,            */

       SG02,     SG05,                1.0,      1.0,
       SG02,     SG09,                1.0,      1.0,

       SG05,     SG02,                1.0,      1.0,
       SG05,     SG09,                1.0,      1.0,

       SG09,     SG02,                1.0,      1.0,
       SG09,     SG05,                1.0,      1.0,

       STOP};


/*     SignaalGroep_TIJDEN tabel                                */
struct SG_TIJDEN  SG_TIJDEN_tabel[] = {
/*            instellingen van de tijden:                       */
/*     sg:    GG_TIJD:  VG_TIJD:  GGL_TIJD:  GL_TIJD:  GR_TIJD: */
/*     SGn,    x.y,      x.y,      x.y,       x.y,      x.y,    */
       SG02,   7.0,      7.0,      3.0,       3.0,      2.0,
       SG05,   7.0,      7.0,      3.0,       3.0,      2.0,
       SG09,   7.0,      7.0,      3.0,       3.0,      2.0,
       STOP};


/*     MG_TIJDEN tabel                                          */
struct MG_TIJDEN  MG_TIJDEN_tabel[] = {
/*            instellingen (x.y of NG) van de tijden:           */
/*     sg:    MG_TIJD:  MG_TIJD1:  MG_TIJD2:  MG_TIJD3:         */
/*     SGn,    x.y,      x.y,       x.y,       x.y,             */
       SG02,  20.0,       NG,        NG,        NG,     
       SG05,  20.0,       NG,        NG,        NG,     
       SG09,  20.0,       NG,        NG,        NG,     
       STOP};


/*     HiaatTIJDEN tabel                                        */
struct H_TIJDEN  H_TIJDEN_tabel[] = {
/*               instellingen (x.y of NG) van de tijden:        */
/*     sg:       H1e_TIJD:   H2e_TIJD:                          */
/*     SGn,       x.y,        x.y,                              */
       SG02,      2.0,         NG,      
       SG05,      2.0,         NG,      
       SG09,      2.0,         NG,      
       STOP};


/*     SignaalGroep-DETECTIE tabel                              */
struct SG_DETECTIE           SG_DETECTIE_tabel[] = {
/*     D():     type:        sg:     toewijzing:                */
/*     SGn_i,   DP (of DK),  SGn,    AVR + BS_H5p + H1e + H2e,  */
       SG02_1,  DP,          SG02,   AVR + BS_H5p + H1e,
       SG05_1,  DP,          SG05,   AVR + BS_H5p + H1e,
       SG09_1,  DP,          SG09,   AVR + BS_H5p + H1e,

       STOP};


/*     extra PARMS tabel  */
struct EPARMS       EPARMS_tabel[] = {
/*     EPARM(),     instelling    */
       STOP};


/*     extra EGGPARMS tabel  */
struct EGGPARMS       EGGPARMS_tabel[] = {
/*     EGGPARM(),     instelling    */
       jaar_inst,   2002, /* 2002 */
       maand_inst,     8, /* augustus */
       dag_inst,      11, /* de 11e */
                          /* bovenstaande datum is dus 11 augustus 2002 */
       weekdag_inst,   1, /* maandag */
       uur_inst,      16, 
       minuut_inst,   33,
       STOP};


/*     REGELING tabel                                           */
struct REGELING   REGELING_tabel[] = {
/*     Nummer,  */
       1,
       STOP};



struct BK_OPTIE BO_OP_tabel[] = { STOP};
struct SG_OPTIE MA_OP_tabel[] = { STOP};
struct SG_BK_OPTIE PPP_OP_tabel[] = { STOP};
struct SG_OPTIE MVG_OP_tabel[] = { STOP};
struct SG_OPTIE TR_OP_tabel[] = { STOP};
struct SG_OPTIE VAA_OP_tabel[] = { STOP};
struct SG_OPTIE PPV_OP_tabel[] = { STOP};
struct SG_OPTIE PPB_OP_tabel[] = { STOP};
struct SG_BK_OPTIE PPA_OP_tabel[] = { STOP};
struct SG_BK_OPTIE VNM_OP_tabel[] = { STOP};
struct SG_OPTIE AFK_OP_tabel[] = { STOP};
struct SG_OPTIE BL_OP_tabel[] = { STOP};
struct SG_OPTIE RVG_OP_tabel[] = { STOP};
struct SG_OPTIE VAG_OP_tabel[] = { STOP};
struct SG_OPTIE VMG_OP_tabel[] = { STOP};
struct KOPPEL KOPPEL_tabel[] = { STOP};
struct WB WB_tabel[] = { STOP};
struct FICT_CONFLICT FICT_CONFLICT_tabel[] = { STOP};
struct SG_BS_H5t SG_BS_H5t_tabel[] = { STOP};
struct SG_BS_H5ac SG_BS_H5ac_tabel[] = { STOP};
struct SG_BS_H66 SG_BS_H66_tabel[] = { STOP};
struct E_MG_TIJDEN E_MG_TIJDEN_tabel[] = { STOP};
struct E_H_TIJDEN E_H_TIJDEN_tabel[] = { STOP};
struct SG_RGA SG_RGA_tabel[] = { STOP};
struct FIETS_VOETG_R FIETS_VOETG_R_tabel[] = { STOP};
struct SG_MAH3 SG_MAH3_tabel[] = { STOP};
struct SG_PPAH SG_PPAH_tabel[] = { STOP};
struct SG_WSRH SG_WSRH_tabel[] = { STOP};
struct TIJDEN TIJDEN_tabel[] = { STOP};
struct KLOKKEN KLOKKEN_tabel[] = { STOP};
struct SCHAKELAAR SCHAKELAAR_tabel[] = { STOP};
